@@ -1,5 +1,6 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 #include <errno.h>
 
@@ -67,3 +68,37 @@ gint launch_xmame(const gchar *romname, gboolean use_sound, gboolean fullscreen,
 
 	return status;
 }//launch_xmame
+
+gchar*	xmame_get_rompath_from_xmamerc(const gchar *filename) {
+	gchar	*contents = NULL,
+		*cursor = NULL,
+		*rompath = NULL,
+		**lines = NULL;
+
+	if(!g_file_get_contents(filename, &contents, NULL, NULL)) {
+		return NULL;
+	}// couldn't read file
+
+	if(!(lines = g_strsplit(contents, "\n", 0))) {
+		g_free(contents);
+		return NULL;
+	}// couldn't split into lines
+
+	g_free(contents);
+
+	for(cursor = *lines; cursor; ++cursor) {
+		if(strstr(cursor, "rompath") == cursor) {
+			gchar *tmp = (gchar*)g_malloc(sizeof(gchar) * (strlen(cursor) + 1));
+			rompath = (gchar*)g_malloc(sizeof(gchar) * (strlen(cursor) + 1));
+
+			sscanf(cursor, "%s%s", tmp, rompath);
+			g_free(tmp);
+			break;
+		}// got rompath line
+	}// for each line
+
+	g_strfreev(lines);
+
+	return rompath;
+}// xmame_get_rompath_from_xmamerc
+
